==> nextcloud-29.0.10.tgz: nextcloud/apps/user_status/l10n/ug.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "يېقىنقى ھالەت",
    "No recent status changes" : "يېقىنقى ھالەت ئۆزگەرمىدى",
    "In a meeting" : "بىر يىغىندا",
    "Commuting" : "سەپەرگە چىقىش",
    "Out sick" : "كېسەل",
    "Vacationing" : "دەم ئېلىش",
    "Out of office" : "ئىشخانىدىن چىقتى",
    "Working remotely" : "يىراقتىن ئىشلەش",
    "In a call" : "تېلېفوندا",
    "User status" : "ئىشلەتكۈچى ھالىتى",
    "Clear status after" : "كېيىنكى ھالەتنى ئېنىقلاش",
    "Emoji for your status message" : "ھالەت ئۇچۇرىڭىز ئۈچۈن Emoji",
    "What is your status?" : "ئەھۋالىڭىز نېمە؟",
    "Predefined statuses" : "ئالدىن بېكىتىلگەن ھالەت",
    "Previously set" : "ئىلگىرى تەڭشەلگەن",
    "Reset status" : "ھالىتىنى ئەسلىگە كەلتۈرۈش",
    "Set status" : "ھالەت بەلگىلەڭ",
    "Online status" : "توردىكى ئورنى",
    "Status message" : "ھالەت ئۇچۇرى",
    "Set absence period" : "يوقلۇق ۋاقتىنى بەلگىلەڭ",
    "Set absence period and replacement" : "يوقلۇق ۋاقتى ۋە ئورنىنى بەلگىلەڭ",
    "Your status was set automatically" : "ھالىتىڭىز ئاپتوماتىك تەڭشەلدى",
    "Clear status message" : "ھالەت ئۇچۇرىنى تازىلاش",
    "Set status message" : "ھالەت ئۇچۇرىنى بەلگىلەڭ",
    "Reset status to \"{icon} {message}\"" : "ھالەتنى \"{سىنبەلگىسى} {ئۇچۇر}\" غا قايتۇرۇڭ",
    "Reset status to \"{message}\"" : "ھالەتنى \"{ئۇچۇر}\" غا قايتۇرۇڭ",
    "Reset status to \"{icon}\"" : "ھالەتنى \"{سىنبەلگە}\" گە قايتۇرۇڭ",
    "There was an error saving the status" : "ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى",
    "There was an error clearing the status" : "ھالەتنى تازىلاشتا خاتالىق كۆرۈلدى",
    "There was an error reverting the status" : "ھالەتنى ئەسلىگە كەلتۈرۈشتە خاتالىق كۆرۈلدى",
    "Don't clear" : "ئېنىق ئەمەس",
    "Today" : "بۈگۈن",
    "This week" : "بۇ ھەپتە",
    "Online" : "توردا",
    "Away" : "يىراق",
    "Do not disturb" : "ئاۋارە قىلماڭ",
    "Invisible" : "كۆرۈنمەيدۇ",
    "Offline" : "تورسىز",
    "There was an error saving the new status" : "يېڭى ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى",
    "30 minutes" : "30 مىنۇت",
    "1 hour" : "1 سائەت",
    "4 hours" : "4 سائەت",
    "Mute all notifications" : "بارلىق ئۇقتۇرۇشلارنى ئاۋازسىز قىلىڭ",
    "Appear offline" : "تورسىز كۆرۈنۈش"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-30.0.5.tgz: nextcloud/apps/user_status/l10n/ug.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "يېقىنقى ھالەت",
    "No recent status changes" : "يېقىنقى ھالەت ئۆزگەرمىدى",
    "In a meeting" : "بىر يىغىندا",
    "Commuting" : "سەپەرگە چىقىش",
    "Out sick" : "كېسەل",
    "Vacationing" : "دەم ئېلىش",
    "Out of office" : "ئىشخانىدىن چىقتى",
    "Working remotely" : "يىراقتىن ئىشلەش",
    "In a call" : "تېلېفوندا",
    "User status" : "ئىشلەتكۈچى ھالىتى",
    "Clear status after" : "كېيىنكى ھالەتنى ئېنىقلاش",
    "Emoji for your status message" : "ھالەت ئۇچۇرىڭىز ئۈچۈن Emoji",
    "What is your status?" : "ئەھۋالىڭىز نېمە؟",
    "Predefined statuses" : "ئالدىن بېكىتىلگەن ھالەت",
    "Previously set" : "ئىلگىرى تەڭشەلگەن",
    "Reset status" : "ھالىتىنى ئەسلىگە كەلتۈرۈش",
    "Set status" : "ھالەت بەلگىلەڭ",
    "Online status" : "توردىكى ئورنى",
    "Status message" : "ھالەت ئۇچۇرى",
    "Set absence period" : "يوقلۇق ۋاقتىنى بەلگىلەڭ",
    "Set absence period and replacement" : "يوقلۇق ۋاقتى ۋە ئورنىنى بەلگىلەڭ",
    "Your status was set automatically" : "ھالىتىڭىز ئاپتوماتىك تەڭشەلدى",
    "Clear status message" : "ھالەت ئۇچۇرىنى تازىلاش",
    "Set status message" : "ھالەت ئۇچۇرىنى بەلگىلەڭ",
    "Reset status to \"{icon} {message}\"" : "ھالەتنى \"{icon} {message}\" غا قايتۇرۇڭ",
    "Reset status to \"{message}\"" : "ھالەتنى \"{message}\" غا قايتۇرۇڭ",
    "Reset status to \"{icon}\"" : "ھالەتنى \"{icon}\" گە قايتۇرۇڭ",
    "There was an error saving the status" : "ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى",
    "There was an error clearing the status" : "ھالەتنى تازىلاشتا خاتالىق كۆرۈلدى",
    "There was an error reverting the status" : "ھالەتنى ئەسلىگە كەلتۈرۈشتە خاتالىق كۆرۈلدى",
    "Don't clear" : "ئېنىق ئەمەس",
    "Today" : "بۈگۈن",
    "This week" : "بۇ ھەپتە",
    "Online" : "توردا",
    "Away" : "يىراق",
    "Do not disturb" : "ئاۋارە قىلماڭ",
    "Invisible" : "كۆرۈنمەيدۇ",
    "Offline" : "تورسىز",
    "There was an error saving the new status" : "يېڭى ھالەتنى ساقلاشتا خاتالىق كۆرۈلدى",
    "30 minutes" : "30 مىنۇت",
    "1 hour" : "1 سائەت",
    "4 hours" : "4 سائەت",
    "Mute all notifications" : "بارلىق ئۇقتۇرۇشلارنى ئاۋازسىز قىلىڭ",
    "Appear offline" : "تورسىز كۆرۈنۈش"
},
"nplurals=2; plural=(n != 1);");
